@@ -1,4 +1,5 @@
 from .utils import get_execution_time
-from .utils import update_github
+from .utils import update_github_file
+from .utils import download_github_file
 from .watcher import Watcher
 from .shioaji_wrapper import ShioajiWrapper
